==> connector-service-1.0.2-20200914.081234-6-sources.jar: com/bizvane/connectorservice/entity/common/MemberLoginRequestVO.java <==
package com.bizvane.connectorservice.entity.common;

import com.alibaba.fastjson.JSONObject;
import com.bizvane.connectorservice.entity.base.BaseModel;

/**
 * @author liuying
 * @date 2018/8/9
 * @description
 */

public class MemberLoginRequestVO extends BaseModel {

    /**
     * 微信用户的openId
     */
    private String openId;

    /**
     * 微信用户的unionId
     */
    private String unionId;

    /**
     * 登陆手机号
     */
    private String phone;

    /**
     * 开卡门店编号
     */
    private String openStoreCode;

    /**
     * 开卡导购编号
     */
    private String openGuideCode;

    /**
     * 绑卡来源
     */
    private String source;

    private String taobaoNick;

    /**
     * 手机区域号
     * */
    private String phoneAreaCode;

    public String getPhoneAreaCode() {
        return phoneAreaCode;
    }

    public void setPhoneAreaCode(String phoneAreaCode) {
        this.phoneAreaCode = phoneAreaCode;
    }

    public String getOpenId() {
        return openId;
    }

    public void setOpenId(String openId) {
        this.openId = openId;
    }

    public String getUnionId() {
        return unionId;
    }

    public void setUnionId(String unionId) {
        this.unionId = unionId;
    }

    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }

    public String getOpenStoreCode() {
        return openStoreCode;
    }

    public void setOpenStoreCode(String openStoreCode) {
        this.openStoreCode = openStoreCode;
    }

    public String getOpenGuideCode() {
        return openGuideCode;
    }

    public void setOpenGuideCode(String openGuideCode) {
        this.openGuideCode = openGuideCode;
    }

    public String getSource() {
        return source;
    }

    public void setSource(String source) {
        this.source = source;
    }

    public String getTaobaoNick() {
        return taobaoNick;
    }

    public void setTaobaoNick(String taobaoNick) {
        this.taobaoNick = taobaoNick;
    }
}

==> connector-service-1.0.2-20201114.070932-41-sources.jar: com/bizvane/connectorservice/entity/common/MemberLoginRequestVO.java <==
package com.bizvane.connectorservice.entity.common;

import com.alibaba.fastjson.JSONObject;
import com.bizvane.connectorservice.entity.base.BaseModel;
import lombok.ToString;

/**
 * @author liuying
 * @date 2018/8/9
 * @description
 */
@ToString
public class MemberLoginRequestVO extends BaseModel {

    /**
     * 微信用户的openId
     */
    private String openId;

    /**
     * 微信用户的unionId
     */
    private String unionId;

    /**
     * 登陆手机号
     */
    private String phone;

    /**
     * 开卡门店编号
     */
    private String openStoreCode;

    /**
     * 开卡导购编号
     */
    private String openGuideCode;

    /**
     * 绑卡来源
     */
    private String source;

    private String taobaoNick;

    /**
     * 手机区域号
     * */
    private String phoneAreaCode;

    /**
     * 会员唯一标识 (雷朵)
     */
    private String erpId;


    public String getPhoneAreaCode() {
        return phoneAreaCode;
    }

    public void setPhoneAreaCode(String phoneAreaCode) {
        this.phoneAreaCode = phoneAreaCode;
    }

    public String getOpenId() {
        return openId;
    }

    public void setOpenId(String openId) {
        this.openId = openId;
    }

    public String getUnionId() {
        return unionId;
    }

    public void setUnionId(String unionId) {
        this.unionId = unionId;
    }

    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }

    public String getOpenStoreCode() {
        return openStoreCode;
    }

    public void setOpenStoreCode(String openStoreCode) {
        this.openStoreCode = openStoreCode;
    }

    public String getOpenGuideCode() {
        return openGuideCode;
    }

    public void setOpenGuideCode(String openGuideCode) {
        this.openGuideCode = openGuideCode;
    }

    public String getSource() {
        return source;
    }

    public void setSource(String source) {
        this.source = source;
    }

    public String getTaobaoNick() {
        return taobaoNick;
    }

    public void setTaobaoNick(String taobaoNick) {
        this.taobaoNick = taobaoNick;
    }

    public String getErpId() {
        return erpId;
    }

    public void setErpId(String erpId) {
        this.erpId = erpId;
    }
}
